SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN = (function ( self ) {
    var _timeout = 0;
    var _current_window;
    var _current_property;
    
    function ____ ( fct ) {
        _timeout += fct;
    }
    
    self.do = function () {
        switch ( __shinken_test_type ) {
            case "00045":
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STRING.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.ADDRESS ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.USE ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.HOSTGROUPS ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RANGE.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.BUSINESS_IMPACT ) );
                
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.ADVANCED ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.BUSINESS_IMPACT_MODULATIONS ) );
                
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.MONITORING ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_SINGLE_SELECT.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.CHECK_PERIOD ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_BOOLEAN.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.ACTIVE_CHECKS_ENABLED ) );
                break;
            case "00047":
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                break;
            case "00067":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STRING.TEST.validate_EMPTY_Step3( _timeout, PROPERTY.CONST.NAME.ADDRESS ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00068":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STRING.TEST.validate_FORCE_TO_DEFAULT_Step3( _timeout, PROPERTY.CONST.NAME.ADDRESS ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00069":
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STRING.TEST.validate_SET_Step3( _timeout, PROPERTY.CONST.NAME.ADDRESS ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00070":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone(_timeout, true) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.SYNCHRONIZER.ACTION.changeAddressDuplicateBehaviour( _timeout, "duplicated_accepted" ) );
                        break;
                    case 2:
                    case 3:
                        _current_property = PROPERTY.CONST.NAME.USE;
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, _current_property, 'ADD_BEFORE' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                        break;
                    case 4:
                    case 5:
                        _current_property = PROPERTY.CONST.NAME.HOSTGROUPS;
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, _current_property, 'ADD_BEFORE' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                        break;
                }
                break;
            case "00071":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, PROPERTY.CONST.NAME.USE, 'ADD_AFTER' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00072":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, PROPERTY.CONST.NAME.USE, 'ADD_FIRST' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00073":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_ADD_Step3( _timeout, PROPERTY.CONST.NAME.USE, 'ADD_LAST' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00074":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_MOVE_Step3( _timeout, PROPERTY.CONST.NAME.USE, 'MOVE_BEFORE' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00075":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_MOVE_Step3( _timeout, PROPERTY.CONST.NAME.USE, 'MOVE_AFTER' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00076":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_MOVE_Step3( _timeout, PROPERTY.CONST.NAME.USE, 'MOVE_FIRST' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00077":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_MOVE_Step3( _timeout, PROPERTY.CONST.NAME.USE, 'MOVE_LAST' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00078":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_REPLACE_Step3( _timeout, PROPERTY.CONST.NAME.USE ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00079":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_REMOVE_Step3( _timeout, PROPERTY.CONST.NAME.USE ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00080":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTI_SELECT.TEST.validate_SET_Step3( _timeout, PROPERTY.CONST.NAME.USE ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00092":
                if ( __version_shinken !== SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.UNKNOWN ) {
                    console.error( "[TEST AUTO]", "[TEST ABORT]" ,"WAITING FOR DEV LEO" );
                    break;
                }
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTILINE.TEST.validate_step3( _timeout, PROPERTY.CONST.NAME.NOTE_MULTI_URL ) );
                break;
            case "00093":
                if ( __version_shinken !== SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.UNKNOWN ) {
                    console.error( "[TEST AUTO]", "[TEST ABORT]" ,"WAITING FOR DEV LEO" );
                    break;
                }
                _current_property = PROPERTY.CONST.NAME.NOTE_MULTI_URL;
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, _current_property, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.setValue( _timeout, _current_property, [['test_auto_1', 'http://test_auto_1', 'picture', 'POPUP(70)']] ) );
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_MULTILINE.TEST.validSelectorState( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_TYPE, 0, SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STYLE_CONST.STATE.USER_SET ) );
                        break;
                    case 2:
                    case 3:
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_TYPE, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.LAST, 0 ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_TYPE, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.FIRST, 0 ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_TYPE, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.POSITION, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_INDEX, 2, 0 ) );
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_TYPE, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.AFTER, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_URL_NAME, "test_auto_3", 0 ) );
                        break;
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_TYPE, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.BEFORE, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_MULTI_LINE.selectOptionInLine( _timeout, _current_property, COMPONENT.UrlLine.CONST.SELECTORS.POSITION_URL_NAME, "test_auto_3", 0 ) );
                        break;
                }
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00094":
                _current_property = PROPERTY.CONST.NAME.BUSINESS_IMPACT;
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, 200 ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, _current_property, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.EMPTY ) );
                        break;
                }
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00123":
            case "00126":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone(_timeout, __shinken_test_type !== "00123") );
                        
                        break;
                    case 2:
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 6:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 7:
                    case 8:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REPLACE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_PLUS, PROPERTY.CONST.MASS_CHANGE.PLUS_ACTION.OFF ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ELEMENT_SINGLE, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ELEMENT_EXTRA, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                        _timeout += 2000;
                        break;
                    case 9:
                    case 10:
                    case 11:
                    case 12:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                        break;
                    case 13:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                        break;
                    case 14:
                    case 15:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, 'test_auto_new' ) );
                        break;
                    case 16:
                    case 17:
                    case 18:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, 'test_auto_new' ) );
                        break;
                    case 19:
                    case 20:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, 'test_auto_new' ) );
                        break;
                    case 21:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 22:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 23:
                    case 24:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_PLUS, PROPERTY.CONST.MASS_CHANGE.PLUS_ACTION.ON ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.EDITION_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_VALID.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 25:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACT.TEST_AUTO_VALID.DATA[ 'contact_name' ] ) );
                        break;
                    case 26:
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.REMOVE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.CONTACTGROUP.TEST_AUTO_DISABLED.DATA[ 'contactgroup_name' ] ) );
                        break;
                    case 27:
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.GENERIC ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.USE, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.HOSTTPLS.TEST_AUTO_VALID_WITH_USER_RIGHTS_1.DATA[ 'name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_EXTRA, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.LAST ) );
                        break;
                    case 28:
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.GENERIC ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.USE, SHINKEN.TOOLS.TEST_AUTO.CONST_SOURCE_INTERNAL.DEFAULT_CONFIG_TEST_AUTO_VALID.HOSTTPLS.TEST_AUTO_VALID_WITH_USER_RIGHTS_4.DATA[ 'name' ] ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION_EXTRA, PROPERTY.CONST.MASS_CHANGE.ACTION_EXTRA.LAST ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACTS, 'admin' ) );
                        break;
                    case 29:
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.VIEW_CONTACT_GROUPS, 'test_auto_disabled' ) );
                        break;
                    case 30:
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACT_GROUPS, PROPERTY.CONST.CUSTOM_SELECT.NONE ) );
                        break;
                }
                if (__phase !== 1 ) {
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                    ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                }
                break;
            case "00127":
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.HOSTGROUP_NAME, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValueWithSynchro( _timeout, PROPERTY.CONST.NAME.HOSTGROUP_NAME, 'test_auto_valid' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00128":
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.EXCLUDE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.EXCLUDE, 'test_auto_valid' ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step3ToStep4( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            case "00129":
                switch ( __phase ) {
                    case 1:
                        PROPERTY.UserRightsBehaviour.has_everybody_default = false;
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACTS, "test_auto_valid" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.GENERIC ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.USE, "test_auto_valid" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.NONE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 2 ) );
                        break;
                    case 2:
                        PROPERTY.UserRightsBehaviour.has_everybody_default = true;
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.PROPERTIES ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACTS, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.ADD ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.NOTIFICATION_CONTACTS, "test_auto_valid" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.clickOnTabStep3( _timeout, WINDOW.CONST.ELEMENT.GENERIC ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.USE, "test_auto_valid" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.USE, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.NONE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WINDOW.TEST.counter( _timeout, "id-shinken-window-user-rights-mass-change", 0, 0, undefined, 4 ) );
                        break;
                    case 3:
                        break;
                }
                break;
            case "00174":
                ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.save_external_shinken_element( _timeout, [200, 202] ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.selectAndGoStep1( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step1ToStep2( _timeout, CONTROLLER.CONST.MASS_CHANGE.TYPE.CHECKS_EXCLUDE ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.selectOptionInPropertySelector( _timeout, PROPERTY.CONST.NAME.SERVICE_EXCLUDES, PROPERTY.CONST.MASS_CHANGE.SELECTOR.ACTION, PROPERTY.CONST.MASS_CHANGE.ACTION.SET ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.SERVICE_EXCLUDES, "xxx" ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_EXCLUDE.ACTION.clickOnToggleAll( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE.ACTION.step2ToStep3( _timeout ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_STEP_4.TEST.validate_Step4( _timeout ) );
                break;
            default:
                ____( SHINKEN.TOOLS.TEST_AUTO_LIST_RUN.do( _timeout ) );
                break;
        }
        return _timeout;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_MASS_CHANGE_RUN || {} );
